@@ -1,20 +1,18 @@
 #![no_std]
 #![no_main]
 
+use bsp::hal;
+use feather_m4 as bsp;
 #[cfg(not(feature = "use_semihosting"))]
 use panic_halt as _;
 #[cfg(feature = "use_semihosting")]
 use panic_semihosting as _;
 
-use bsp::hal;
-use bsp::pac;
-use feather_m0 as bsp;
-
-use bsp::{entry, pin_alias};
+use bsp::entry;
 use hal::clock::GenericClockController;
 use hal::delay::Delay;
+use hal::pac::{CorePeripherals, Peripherals};
 use hal::prelude::*;
-use pac::{CorePeripherals, Peripherals};
 
 #[entry]
 fn main() -> ! {
@@ -22,17 +20,18 @@ fn main() -> ! {
     let core = CorePeripherals::take().unwrap();
     let mut clocks = GenericClockController::with_external_32kosc(
         peripherals.GCLK,
-        &mut peripherals.PM,
-        &mut peripherals.SYSCTRL,
+        &mut peripherals.MCLK,
+        &mut peripherals.OSC32KCTRL,
+        &mut peripherals.OSCCTRL,
         &mut peripherals.NVMCTRL,
     );
-    let pins = bsp::Pins::new(peripherals.PORT);
-    let mut red_led: bsp::RedLed = pin_alias!(pins.red_led).into();
+    let mut pins = bsp::Pins::new(peripherals.PORT);
+    let mut red_led = pins.d13.into_open_drain_output(&mut pins.port);
     let mut delay = Delay::new(core.SYST, &mut clocks);
     loop {
-        delay.delay_ms(200u8);
+        delay.delay_ms(2000u16);
         red_led.set_high().unwrap();
-        delay.delay_ms(200u8);
+        delay.delay_ms(2000u16);
         red_led.set_low().unwrap();
     }
 }
