@@ -4,34 +4,34 @@
 #![no_std]
 #![no_main]
 
-use cortex_m::asm;
-
-#[cfg(not(feature = "use_semihosting"))]
-use panic_halt as _;
-#[cfg(feature = "use_semihosting")]
-use panic_semihosting as _;
-
 use bsp::hal;
-use bsp::pac;
-use feather_m0 as bsp;
+use cortex_m::asm;
+use feather_m4 as bsp;
+use panic_halt as _;
+
+use hal::{
+    clock::GenericClockController,
+    entry,
+    pac::{CorePeripherals, Peripherals},
+};
 
-use bsp::entry;
-use hal::clock::GenericClockController;
 use hal::dmac::{DmaController, PriorityLevel, Transfer, TriggerAction, TriggerSource};
-use pac::Peripherals;
 
 #[entry]
 fn main() -> ! {
     let mut peripherals = Peripherals::take().unwrap();
-    let _clocks = GenericClockController::with_internal_32kosc(
+    let core = CorePeripherals::take().unwrap();
+    let _clocks = GenericClockController::with_external_32kosc(
         peripherals.GCLK,
-        &mut peripherals.PM,
-        &mut peripherals.SYSCTRL,
+        &mut peripherals.MCLK,
+        &mut peripherals.OSC32KCTRL,
+        &mut peripherals.OSCCTRL,
         &mut peripherals.NVMCTRL,
     );
 
     let mut pm = peripherals.PM;
     let dmac = peripherals.DMAC;
+    let _nvic = core.NVIC;
 
     // Initialize buffers
     const LENGTH: usize = 50;
@@ -51,8 +51,8 @@ fn main() -> ! {
     // Setup a DMA transfer (memory-to-memory -> incrementing source, incrementing
     // destination) with a 8-bit beat size
     let xfer = Transfer::new_from_arrays(chan0, buf_src, buf_dest, false)
-        .with_waker(|_status| asm::nop())
         .begin(TriggerSource::DISABLE, TriggerAction::BLOCK);
+
     // Wait for transfer to complete and grab resulting buffers
     let (chan0, buf_src, buf_dest) = xfer.wait();
 
@@ -77,8 +77,8 @@ fn main() -> ! {
     let _b = buf_16[LENGTH - 1];
 
     // Manipulate the returned buffer for fun
-    for (i, item) in buf_16.iter_mut().enumerate() {
-        *item = i as u16;
+    for i in 0..LENGTH {
+        buf_16[i] = i as u16;
     }
 
     // Setup a DMA transfer (memory-to-memory -> incrementing source, fixed
