@@ -1,23 +1,23 @@
 #![no_std]
 #![no_main]
 
-use cortex_m_rt::entry;
+// Pulse Width Modulation
+//
+// cargo build --features="unproven"
 
+use bsp::hal;
+use feather_m4 as bsp;
 #[cfg(not(feature = "use_semihosting"))]
 use panic_halt as _;
 #[cfg(feature = "use_semihosting")]
 use panic_semihosting as _;
 
-use bsp::hal;
-use bsp::pac;
-use feather_m0 as bsp;
-
-use bsp::pin_alias;
+use cortex_m_rt::entry;
 use hal::clock::GenericClockController;
 use hal::delay::Delay;
+use hal::pac::{CorePeripherals, Peripherals};
 use hal::prelude::*;
-use hal::pwm::Pwm3;
-use pac::{CorePeripherals, Peripherals};
+use hal::pwm::Pwm4;
 
 #[entry]
 fn main() -> ! {
@@ -26,28 +26,32 @@ fn main() -> ! {
 
     let mut clocks = GenericClockController::with_external_32kosc(
         peripherals.GCLK,
-        &mut peripherals.PM,
-        &mut peripherals.SYSCTRL,
+        &mut peripherals.MCLK,
+        &mut peripherals.OSC32KCTRL,
+        &mut peripherals.OSCCTRL,
         &mut peripherals.NVMCTRL,
     );
-    let mut delay = Delay::new(core.SYST, &mut clocks);
-    let pins = bsp::Pins::new(peripherals.PORT);
 
-    let _d5: bsp::D5Pwm = pin_alias!(pins.d5_pwm).into();
+    let mut delay = Delay::new(core.SYST, &mut clocks);
+    let mut pins = bsp::Pins::new(peripherals.PORT);
+    let red_led = pins.d13.into_function_e(&mut pins.port);
 
     let gclk0 = clocks.gclk0();
-    let mut pwm3 = Pwm3::new(
-        &clocks.tcc2_tc3(&gclk0).unwrap(),
+    let mut pwm4 = Pwm4::new(
+        &clocks.tc4_tc5(&gclk0).unwrap(),
         1.khz(),
-        peripherals.TC3,
-        &mut peripherals.PM,
+        peripherals.TC4,
+        hal::pwm::TC4Pinout::Pa23(red_led),
+        &mut peripherals.MCLK,
     );
-    let max_duty = pwm3.get_max_duty();
+    let max_duty = pwm4.get_max_duty();
 
+    // The red led will light up and toggle between 2 brightness
+    // levels every second.
     loop {
-        pwm3.set_duty(max_duty / 2);
+        pwm4.set_duty(max_duty / 2);
         delay.delay_ms(1000u16);
-        pwm3.set_duty(max_duty / 8);
+        pwm4.set_duty(max_duty / 8);
         delay.delay_ms(1000u16);
     }
 }
