@@ -1,55 +1,54 @@
 #![no_std]
 #![no_main]
 
+use bsp::hal;
+use feather_m4 as bsp;
 #[cfg(not(feature = "use_semihosting"))]
 use panic_halt as _;
 #[cfg(feature = "use_semihosting")]
 use panic_semihosting as _;
 
-use cortex_m::asm::delay as cycle_delay;
-use cortex_m::peripheral::NVIC;
+use bsp::entry;
+use hal::clock::GenericClockController;
+use hal::pac::{interrupt, CorePeripherals, Peripherals};
+use hal::usb::UsbBus;
+
 use usb_device::bus::UsbBusAllocator;
 use usb_device::prelude::*;
 use usbd_serial::{SerialPort, USB_CLASS_CDC};
 
-use bsp::hal;
-use bsp::pac;
-use feather_m0 as bsp;
-
-use bsp::{entry, pin_alias};
-use hal::clock::GenericClockController;
-use hal::prelude::*;
-use hal::usb::UsbBus;
-use pac::{interrupt, CorePeripherals, Peripherals};
+use cortex_m::asm::delay as cycle_delay;
+use cortex_m::peripheral::NVIC;
 
 #[entry]
 fn main() -> ! {
     let mut peripherals = Peripherals::take().unwrap();
     let mut core = CorePeripherals::take().unwrap();
-    let mut clocks = GenericClockController::with_internal_32kosc(
+    let mut clocks = GenericClockController::with_external_32kosc(
         peripherals.GCLK,
-        &mut peripherals.PM,
-        &mut peripherals.SYSCTRL,
+        &mut peripherals.MCLK,
+        &mut peripherals.OSC32KCTRL,
+        &mut peripherals.OSCCTRL,
         &mut peripherals.NVMCTRL,
     );
-    let pins = bsp::Pins::new(peripherals.PORT);
-    let mut red_led: bsp::RedLed = pin_alias!(pins.red_led).into();
+    let mut pins = bsp::Pins::new(peripherals.PORT);
+    let mut red_led = pins.d13.into_open_drain_output(&mut pins.port);
 
     let bus_allocator = unsafe {
         USB_ALLOCATOR = Some(bsp::usb_allocator(
-            peripherals.USB,
-            &mut clocks,
-            &mut peripherals.PM,
             pins.usb_dm,
             pins.usb_dp,
+            peripherals.USB,
+            &mut clocks,
+            &mut peripherals.MCLK,
         ));
         USB_ALLOCATOR.as_ref().unwrap()
     };
 
     unsafe {
-        USB_SERIAL = Some(SerialPort::new(bus_allocator));
+        USB_SERIAL = Some(SerialPort::new(&bus_allocator));
         USB_BUS = Some(
-            UsbDeviceBuilder::new(bus_allocator, UsbVidPid(0x16c0, 0x27dd))
+            UsbDeviceBuilder::new(&bus_allocator, UsbVidPid(0x16c0, 0x27dd))
                 .manufacturer("Fake company")
                 .product("Serial port")
                 .serial_number("TEST")
@@ -59,15 +58,17 @@ fn main() -> ! {
     }
 
     unsafe {
-        core.NVIC.set_priority(interrupt::USB, 1);
-        NVIC::unmask(interrupt::USB);
+        core.NVIC.set_priority(interrupt::USB_OTHER, 1);
+        core.NVIC.set_priority(interrupt::USB_TRCPT0, 1);
+        core.NVIC.set_priority(interrupt::USB_TRCPT1, 1);
+        NVIC::unmask(interrupt::USB_OTHER);
+        NVIC::unmask(interrupt::USB_TRCPT0);
+        NVIC::unmask(interrupt::USB_TRCPT1);
     }
 
-    // Flash the LED in a spin loop to demonstrate that USB is
-    // entirely interrupt driven.
     loop {
-        cycle_delay(15 * 1024 * 1024);
-        red_led.toggle().ok();
+        cycle_delay(5 * 1024 * 1024);
+        red_led.toggle();
     }
 }
 
@@ -77,8 +78,8 @@ static mut USB_SERIAL: Option<SerialPort<UsbBus>> = None;
 
 fn poll_usb() {
     unsafe {
-        if let Some(usb_dev) = USB_BUS.as_mut() {
-            if let Some(serial) = USB_SERIAL.as_mut() {
+        USB_BUS.as_mut().map(|usb_dev| {
+            USB_SERIAL.as_mut().map(|serial| {
                 usb_dev.poll(&mut [serial]);
                 let mut buf = [0u8; 64];
 
@@ -87,15 +88,25 @@ fn poll_usb() {
                         if i >= count {
                             break;
                         }
-                        serial.write(&[*c]).ok();
+                        serial.write(&[c.clone()]).unwrap();
                     }
                 };
-            };
-        };
+            });
+        });
     };
 }
 
 #[interrupt]
-fn USB() {
+fn USB_OTHER() {
+    poll_usb();
+}
+
+#[interrupt]
+fn USB_TRCPT0() {
+    poll_usb();
+}
+
+#[interrupt]
+fn USB_TRCPT1() {
     poll_usb();
 }
